# mds
Mbed Cloud Connect API allows web applications to communicate with devices. You can subscribe to device resources and read/write values to them. mbed Cloud Connect makes connectivity to devices easy by queuing requests and caching resource values.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import mds 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import mds
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import mds
from mds.rest import ApiException
from pprint import pprint

# Configure API key authorization: Bearer
mds.configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# mds.configuration.api_key_prefix['Authorization'] = 'Bearer'
# create an instance of the API class
api_instance = mds.DeviceRequestsApi()
device_id = 'device_id_example' # str | The device ID generated by Mbed Cloud.
async_id = 'async_id_example' # str | The client-generated ID for matching the correct response delivered via a notification.
body = mds.DeviceRequest() # DeviceRequest | Device request to send.

try:
    # Send an async request to device
    api_instance.v2_device_requests_device_id_post(device_id, async_id, body)
except ApiException as e:
    print("Exception when calling DeviceRequestsApi->v2_device_requests_device_id_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.us-east-1.mbedcloud.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DeviceRequestsApi* | [**v2_device_requests_device_id_post**](docs/DeviceRequestsApi.md#v2_device_requests_device_id_post) | **POST** /v2/device-requests/{device-id} | Send an async request to device
*EndpointsApi* | [**v2_endpoints_device_id_get**](docs/EndpointsApi.md#v2_endpoints_device_id_get) | **GET** /v2/endpoints/{device-id} | List the resources on an endpoint
*EndpointsApi* | [**v2_endpoints_get**](docs/EndpointsApi.md#v2_endpoints_get) | **GET** /v2/endpoints | (DEPRECATED) List registered endpoints. The number of returned endpoints is currently limited to 200.
*NotificationsApi* | [**v2_notification_callback_delete**](docs/NotificationsApi.md#v2_notification_callback_delete) | **DELETE** /v2/notification/callback | Delete callback URL
*NotificationsApi* | [**v2_notification_callback_get**](docs/NotificationsApi.md#v2_notification_callback_get) | **GET** /v2/notification/callback | Check callback URL
*NotificationsApi* | [**v2_notification_callback_put**](docs/NotificationsApi.md#v2_notification_callback_put) | **PUT** /v2/notification/callback | Register a callback URL
*NotificationsApi* | [**v2_notification_pull_delete**](docs/NotificationsApi.md#v2_notification_pull_delete) | **DELETE** /v2/notification/pull | Delete notification Long Poll channel
*NotificationsApi* | [**v2_notification_pull_get**](docs/NotificationsApi.md#v2_notification_pull_get) | **GET** /v2/notification/pull | Get notifications using Long Poll
*ResourcesApi* | [**v2_endpoints_device_id_resource_path_delete**](docs/ResourcesApi.md#v2_endpoints_device_id_resource_path_delete) | **DELETE** /v2/endpoints/{device-id}/{resourcePath} | Delete a resource path
*ResourcesApi* | [**v2_endpoints_device_id_resource_path_get**](docs/ResourcesApi.md#v2_endpoints_device_id_resource_path_get) | **GET** /v2/endpoints/{device-id}/{resourcePath} | Read from a resource
*ResourcesApi* | [**v2_endpoints_device_id_resource_path_post**](docs/ResourcesApi.md#v2_endpoints_device_id_resource_path_post) | **POST** /v2/endpoints/{device-id}/{resourcePath} | Execute a function on a Resource or create new Object instance
*ResourcesApi* | [**v2_endpoints_device_id_resource_path_put**](docs/ResourcesApi.md#v2_endpoints_device_id_resource_path_put) | **PUT** /v2/endpoints/{device-id}/{resourcePath} | Write to a resource or use write-attributes for a resource
*SubscriptionsApi* | [**v2_subscriptions_delete**](docs/SubscriptionsApi.md#v2_subscriptions_delete) | **DELETE** /v2/subscriptions | Remove pre-subscriptions
*SubscriptionsApi* | [**v2_subscriptions_device_id_delete**](docs/SubscriptionsApi.md#v2_subscriptions_device_id_delete) | **DELETE** /v2/subscriptions/{device-id} | Delete subscriptions from an endpoint
*SubscriptionsApi* | [**v2_subscriptions_device_id_get**](docs/SubscriptionsApi.md#v2_subscriptions_device_id_get) | **GET** /v2/subscriptions/{device-id} | Read endpoints subscriptions
*SubscriptionsApi* | [**v2_subscriptions_device_id_resource_path_delete**](docs/SubscriptionsApi.md#v2_subscriptions_device_id_resource_path_delete) | **DELETE** /v2/subscriptions/{device-id}/{resourcePath} | Remove a subscription
*SubscriptionsApi* | [**v2_subscriptions_device_id_resource_path_get**](docs/SubscriptionsApi.md#v2_subscriptions_device_id_resource_path_get) | **GET** /v2/subscriptions/{device-id}/{resourcePath} | Read subscription status
*SubscriptionsApi* | [**v2_subscriptions_device_id_resource_path_put**](docs/SubscriptionsApi.md#v2_subscriptions_device_id_resource_path_put) | **PUT** /v2/subscriptions/{device-id}/{resourcePath} | Subscribe to a resource path
*SubscriptionsApi* | [**v2_subscriptions_get**](docs/SubscriptionsApi.md#v2_subscriptions_get) | **GET** /v2/subscriptions | Get pre-subscriptions
*SubscriptionsApi* | [**v2_subscriptions_put**](docs/SubscriptionsApi.md#v2_subscriptions_put) | **PUT** /v2/subscriptions | Set pre-subscriptions


## Documentation For Models

 - [AsyncID](docs/AsyncID.md)
 - [AsyncIDResponse](docs/AsyncIDResponse.md)
 - [DeviceRequest](docs/DeviceRequest.md)
 - [Endpoint](docs/Endpoint.md)
 - [EndpointData](docs/EndpointData.md)
 - [NotificationData](docs/NotificationData.md)
 - [NotificationMessage](docs/NotificationMessage.md)
 - [Presubscription](docs/Presubscription.md)
 - [PresubscriptionArray](docs/PresubscriptionArray.md)
 - [Resource](docs/Resource.md)
 - [ResourcePath](docs/ResourcePath.md)
 - [ResourcesData](docs/ResourcesData.md)
 - [SubscriptionsList](docs/SubscriptionsList.md)
 - [Webhook](docs/Webhook.md)


## Documentation For Authorization


## Bearer

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author



